Module algorithm

Module algorithm 

Execution algorithms for algorithmic order placement.

Re-exports

pub use iceberg::IcebergAlgorithm;
pub use pegged::PeggedBestAlgorithm;
pub use twap::TwapAlgorithm;
pub use vwap::VwapAlgorithm;
pub use sniper::SniperAlgorithm;
pub use trailing_stop::TrailingStopAlgorithm;

Modules

iceberg
pegged
sniper
trailing_stop
twap
Time-Weighted Average Price (TWAP) execution algorithm.
vwap

Structs

ChildOrderRequest
Represents a child order request from an execution algorithm.

Enums

AlgoStatus
Current status of an execution algorithm.
ChildOrderAction
Actions generated by algorithms for managing their child orders.

Traits

ExecutionAlgorithm
Trait defining the behavior of an execution algorithm.