Module trailing_stop
tesser_
execution
0.9.1
Module trailing_
stop
Module Items
Structs
In tesser_
execution::
algorithm
tesser_execution
::
algorithm
Module
trailing_
stop
Structs

Trailing
Stop
Algorithm
Simple trailing stop that arms once price trades through an activation level and fires a market sell when price retraces by the configured callback percentage.