ExecutionEngine

Struct ExecutionEngine 

pub struct ExecutionEngine { /* private fields */ }
Translates signals into orders using a provided ExecutionClient.

Implementations

Source

impl ExecutionEngine

pub fn new( client: Arc<dyn ExecutionClient>, sizer: Box<dyn OrderSizer>, risk: Arc<dyn PreTradeRiskChecker>, ) -> Self

Instantiate the engine with its dependencies.

pub fn determine_quantity( &self, signal: &Signal, ctx: &RiskContext, ) -> Result<Quantity>

Determine the quantity that should be used for a signal, honoring overrides when present.

pub async fn handle_signal( &self, signal: Signal, ctx: RiskContext, ) -> BrokerResult<Option<Order>>

Consume a signal and forward it to the broker.

pub async fn amend_order( &self, request: OrderUpdateRequest, ) -> BrokerResult<Order>

pub fn client(&self) -> Arc<dyn ExecutionClient>

pub fn sizer(&self) -> &dyn OrderSizer